@@ -508,7 +508,7 @@
 /*
  * GUI dark theme variant
  */
-#if defined(FEAT_GUI_GTK) && defined(USE_GTK3)
+#if (defined(FEAT_GUI_GTK) && defined(USE_GTK3)) || defined(FEAT_GUI_MSWIN)
 # define FEAT_GUI_DARKTHEME
 #endif
 
@@ -905,19 +905,6 @@
 # define FEAT_CLIPBOARD
 #endif
 
-/*
- * +clipboard_provider	Allow Vim to use clipboard providers
- */
-#if defined(FEAT_CLIPBOARD_PROVIDER)
-# ifndef FEAT_EVAL
-#  undef FEAT_CLIPBOARD_PROVIDER
-# else
-#  ifndef FEAT_CLIPBOARD
-#   define FEAT_CLIPBOARD
-#  endif
-# endif
-#endif
-
 #ifdef FEAT_GUI
 # ifndef FEAT_CLIPBOARD
 #  define FEAT_CLIPBOARD
